@@ -15,7 +15,7 @@ using namespace Rcpp;
 //' @param verbose logical. Print updates to console?
 //' @keywords internal
 // [[Rcpp::export]]
-List parse_IMU_C(
+List legacy_parse_IMU_C(
     DataFrame imu_records, RawVector log,
     DataFrame info, int id, int samp_rate,
     bool verbose
@@ -43,7 +43,7 @@ List parse_IMU_C(
       int start_index = indices[i] - 1;
       int end_index = start_index + 8 + sizes[i];
       checksumC(log, start_index, end_index);
-      IntegerVector record_indices = seq(start_index, end_index);
+      // IntegerVector record_indices = seq(start_index, end_index);
       IntegerVector payload_indices = seq(start_index + 8, end_index - 1);
       RawVector payload = log[payload_indices];
       if (payload_indices.size() != sizes[i]) {
@@ -51,7 +51,7 @@ List parse_IMU_C(
       }
 
     //Process the packet
-      DataFrame new_result = payload_parse_sensor_data_25C(
+      DataFrame new_result = legacy_payload_parse_sensor_data_25C(
         payload, info, id, samp_rate, timestamps[i]
       );
 
@@ -67,3 +67,45 @@ List parse_IMU_C(
   return result;
 
 }
+
+//' @rdname legacy_parse_IMU_C
+//' @inheritParams dev_parse_primary_accelerometerC
+// [[Rcpp::export]]
+List dev_parse_IMU_C(
+    List packets, IntegerVector packet_no, List zero_packet,
+    int id, int samp_rate, DataFrame info
+) {
+
+  // Initialize output and loop variables
+  List full_packets(packet_no.size());
+  int index;
+  List packet;
+  RawVector payload;
+
+  // Populate output
+  for (int i = 0; i < packet_no.size(); ++i) {
+
+    index = packet_no[i];
+
+    if (index == -1)  {
+      full_packets[i] = zero_packet;
+      continue;
+    }
+
+    packet = packets[index];
+    payload = packet["payload"];
+
+    if (payload.size() == 1) {
+      full_packets[i] = zero_packet;
+      continue;
+    }
+
+    full_packets[i] = dev_payload_parse_sensor_data_25C(
+      payload, info, id, samp_rate
+    );
+
+  }
+
+  return full_packets;
+
+}
